"""
This module contains the terminal user interface and the webserver (should we move the server to a higher level?).

### Submodules

- **terminal**: Terminal user interface
- **graphical**: Graphical user interface
- **external**: Functions for checking and downloading external dependencies (binaries and data)
- **config**: Configuration file and command line arguments
"""